/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.wizard;

import java.awt.Component;
import java.io.File;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import org.openide.WizardDescriptor;
import org.openide.WizardValidationException;
import org.openide.util.HelpCtx;
import org.openide.util.NbBundle;

/**
 * FilePicker controller to choose a file that contains geometrical information
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages({"ImportShapeFilePicker.error_message.not_a_valid_file=Chosen path is not a valid file"})
public class ImportShapeFilePicker implements WizardDescriptor.ValidatingPanel, ChangeListener {

    private ImportShapeFilePickerPanel filePickerPanel;
    public static final String FILE_PATH = "filePath";
    private WizardDescriptor descriptor;
    private static final String WIZARD_NO_FILE_ERROR_MESSAGE = NbBundle.getMessage(ImportShapeFilePicker.class, "ImportShapeFilePicker.error_message.not_a_valid_file");

    public ImportShapeFilePicker(WizardDescriptor descriptor) {
        this.descriptor = descriptor;
    }

    @Override
    public Component getComponent() {
        if (filePickerPanel == null) {
            filePickerPanel = new ImportShapeFilePickerPanel();
            filePickerPanel.addChangeListener(this);
        }
        return filePickerPanel;
    }

    @Override
    public HelpCtx getHelp() {
        return new HelpCtx("nl.cloudfarming.client.field.wizard.import_geometries");
    }

    @Override
    public void readSettings(Object settings) {
        descriptor = (WizardDescriptor) settings;
        String path = (String) descriptor.getProperty(FILE_PATH);
        filePickerPanel.setChosenFilePath(path);
    }

    @Override
    public void storeSettings(Object settings) {
        descriptor = (WizardDescriptor) settings;
        descriptor.putProperty(FILE_PATH, ((ImportShapeFilePickerPanel)getComponent()).getChosenFilePath());
    }

    @Override
    public boolean isValid() {
        if(isFile(((ImportShapeFilePickerPanel)getComponent()).getChosenFilePath())){
            descriptor.setValid(true);
            descriptor.putProperty(WizardDescriptor.PROP_ERROR_MESSAGE, "");
            return true;
        } else {
            descriptor.setValid(false);
            descriptor.putProperty(WizardDescriptor.PROP_ERROR_MESSAGE, WIZARD_NO_FILE_ERROR_MESSAGE);
            return false;
        }
    }
    
    public boolean isFile(String path){
        return new File(path).isFile();
    } 

    @Override
    public void addChangeListener(ChangeListener l) {
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
    }

    @Override
    public void validate() throws WizardValidationException {
        if (!isValid()) {
            throw new WizardValidationException(filePickerPanel, WizardDescriptor.PROP_ERROR_MESSAGE, WIZARD_NO_FILE_ERROR_MESSAGE);
        }
    }
    
    @Override
    public void stateChanged(ChangeEvent ce) {
        isValid();
    }
}
