/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.wizard;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import javax.swing.*;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.filesystems.FileUtil;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 * FilePicker panel to choose a file containing geometrical
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages({
    "ImportShapeFilePickerPanel.file_label=Enter a file",
    "ImportShapeFilePickerPanel.browse_button.text=Browse...",
    "ImportShapeFilePickerPanel.browse_button.action_command=BROWSE",
    "ImportShapeFilePickerPanel.dialog.title=Choose a file"
})
public class ImportShapeFilePickerPanel extends ASBodyPanel implements DocumentListener {

    private JLabel fileLabel;
    private JTextField filePath;
    private javax.swing.JButton browseButton;
    private static final String BROWSE_BUTTON_TEXT = NbBundle.getMessage(ImportShapeFilePickerPanel.class, "ImportShapeFilePickerPanel.browse_button.text");
    private static final String BROWSE_BUTTON_ACTION_COMMAND = NbBundle.getMessage(ImportShapeFilePickerPanel.class, "ImportShapeFilePickerPanel.browse_button.action_command");
    private static final String DIALOG_TITLE = NbBundle.getMessage(ImportShapeFilePickerPanel.class, "ImportShapeFilePickerPanel.dialog.title");
    private static final String FILE_LABEL_TEXT = NbBundle.getMessage(ImportShapeFilePickerPanel.class, "ImportShapeFilePickerPanel.dialog.title");
    private static final int PATH_WIDTH = 400;
    private List<ChangeListener> changeListeners = new ArrayList<>();
    private ImageIcon titleIcon = new ImageIcon(ImageUtilities.loadImage("nl/cloudfarming/client/field/map_add32.png"));
    
    public ImportShapeFilePickerPanel() {
        super(new MigLayout());
        init();

    }

    public final void init() {
        setIcon(titleIcon);
        this.setName(DIALOG_TITLE);
        fileLabel = new JLabel(FILE_LABEL_TEXT);
        filePath = new JTextField();
        filePath.setPreferredSize(new Dimension(PATH_WIDTH, 0));
        filePath.getDocument().addDocumentListener(this);
        browseButton = new JButton(BROWSE_BUTTON_TEXT);
        browseButton.setActionCommand(BROWSE_BUTTON_ACTION_COMMAND);
        browseButton.addActionListener(new java.awt.event.ActionListener() {

            @Override
            public void actionPerformed(ActionEvent evt) {
                browseButtonActionPerformed(evt);
            }
        });

        this.add(fileLabel);
        this.add(filePath);
        this.add(browseButton);

    }

    private void browseButtonActionPerformed(ActionEvent evt) {
        String command = evt.getActionCommand();
        if (BROWSE_BUTTON_ACTION_COMMAND.equals(command)) {
            JFileChooser chooser = new JFileChooser();
            chooser.setCurrentDirectory(null);
            chooser.setDialogTitle(DIALOG_TITLE);
            chooser.setFileSelectionMode(JFileChooser.FILES_ONLY);
            String path = this.filePath.getText();
            if (path.length() > 0) {
                File f = new File(path);
                if (f.exists()) {
                    chooser.setSelectedFile(f);
                }
            }
            if (JFileChooser.APPROVE_OPTION == chooser.showOpenDialog(this)) {
                File projectDir = chooser.getSelectedFile();
                filePath.setText(FileUtil.normalizeFile(projectDir).getAbsolutePath());
            }
        }
    }

    /**
     * Get the path of the chosen file
     *
     * @return a String containing the path to the chosen file
     */
    protected String getChosenFilePath() {
        return filePath.getText();
    }

    /**
     * Set the path of the file
     *
     * @param path the path to set
     */
    protected void setChosenFilePath(String path) {
        filePath.setText(path);
    }

    public void addChangeListener(ChangeListener l) {
        changeListeners.add(l);
    }

    public void removeChangeListener(ChangeListener l) {
        changeListeners.remove(l);
    }

    private void fireChange() {
        for (ChangeListener listener : changeListeners) {
            listener.stateChanged(new ChangeEvent(this));
        }
    }

    @Override
    public void insertUpdate(DocumentEvent de) {
        fireChange();
    }

    @Override
    public void removeUpdate(DocumentEvent de) {
        fireChange();
    }

    @Override
    public void changedUpdate(DocumentEvent de) {
        fireChange();
    }
}
