/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.wizard;

import java.awt.event.ActionEvent;
import javax.swing.AbstractAction;
import javax.swing.JLabel;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.field.model.FieldService;
import org.openide.DialogDisplayer;
import org.openide.NotifyDescriptor;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionReferences;
import org.openide.awt.ActionRegistration;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;

/**
 * Start up field project wizard to create a field project first.
 *
 * @author Gerben Feenstra
 */
@ActionID(category = "Project", id = "nl.cloudfarming.client.field.ImportAction")
@ActionRegistration(iconBase = "nl/cloudfarming/client/field/map_add.png", displayName = "#Import.geometrical.wizard.name")
@ActionReferences({
    @ActionReference(path = "Menu/File", position = 0)
})
@Messages({
    "Import.geometrical.wizard.name=Import Geometries",
    "import.shape.wizard.warmup.dialog.title=No fieldprovider found",
    "import.shape.wizard.warmup.dialog.text=To import new fields, one or more field projects to store them have to be available. Either create a new field project or open an existing one.",
    "import.shape.wizard.warmup.button.cancel=Cancel"
})
public class ImportShapeWizardWarmup extends AbstractAction {

//    private static final String NEW_FIELD_PROJECT = "New field project";
//    private static final String OPEN_FIELD_PROJECT = "Open existing field project";
    private static final String CANCEL = Bundle.import_shape_wizard_warmup_button_cancel();

    @Override
    public void actionPerformed(ActionEvent e) {

        OuterLoop:
        while (true) {
            if (!fieldProviderPresent()) {
                JPanel myPanel = new WarmupPanel();
                String[] options = new String[]{CANCEL};//, NEW_FIELD_PROJECT, OPEN_FIELD_PROJECT};

                // Create a custom NotifyDescriptor, specify the panel instance as a parameter + other params
                NotifyDescriptor nd = new NotifyDescriptor(
                        myPanel, // instance of your panel
                        Bundle.import_shape_wizard_warmup_dialog_title(), // title of the dialog
                        NotifyDescriptor.YES_NO_OPTION, // it is Yes/No dialog ...
                        NotifyDescriptor.QUESTION_MESSAGE, // ... of a question type => a question mark icon                
                        options,
                        //                null, // we have specified YES_NO_OPTION => can be null, options specified by L&F,
                        // otherwise specify options as:
                        //     new Object[] { NotifyDescriptor.YES_OPTION, ... etc. },
                        CANCEL // default option is "Yes"
                        );

                // let's display the dialog now...
                String result = (String) DialogDisplayer.getDefault().notify(nd);

//                switch (result) {
//                    case NEW_FIELD_PROJECT:
//                        System.out.println("NEW FIELD PROJECT");
//                        break;
//                    case OPEN_FIELD_PROJECT:
//                        System.out.println("OPEN EXISTING");
//                        break;
                    if(result.equals(CANCEL)){
                        break OuterLoop;
                    }
//                }
            }
            else{
                new ImportShapeWizardIterator().actionPerformed(e);   
                break;
            }
        }
    }

    private boolean fieldProviderPresent() {
        FieldService fieldService = Lookup.getDefault().lookup(FieldService.class);
        return fieldService.getFieldProviders().size() > 0;
    }

    private static class WarmupPanel extends JPanel {

        public WarmupPanel() {
            this.setLayout(new MigLayout());
            this.add(new JLabel(Bundle.import_shape_wizard_warmup_dialog_text()));
        }
    }
}
