/**
 * Copyright (C) 2010-2012 Agrosense info@agrosense.eu
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.field.wizard;

import java.util.List;
import javax.swing.DefaultComboBoxModel;
import javax.swing.ImageIcon;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.field.model.FieldProvider;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

/**
 *
 * @author Gerben Feenstra
 */
@NbBundle.Messages({
    "Import.geometrical.wizard.panel.assign_to_fieldproject.message=Select a geometry project to which you want to save the imported geometries.",
    "Import.geometrical.wizard.panel.assign_to_fieldproject.title=Save import."
})
public class SaveImportPanel extends ASBodyPanel {

    private ImageIcon titleIcon = new ImageIcon(ImageUtilities.loadImage("nl/cloudfarming/client/field/map_add32.png"));
    private DefaultComboBoxModel defaultComboBoxModel = new DefaultComboBoxModel();
    private static final String DIALOG_TITLE = Bundle.Import_geometrical_wizard_panel_assign_to_fieldproject_title();
   
    public SaveImportPanel(){       
        super(new MigLayout());
        init();
    }

    /**
     * Init panel
     */
    private void init(){
        this.setIcon(titleIcon);
        this.setName(DIALOG_TITLE);
        this.add(new JLabel(Bundle.Import_geometrical_wizard_panel_assign_to_fieldproject_message()), "wrap");
        this.add(new JComboBox(defaultComboBoxModel), "gaptop 20");
    }
        
    /**
     * Set available fieldproviders
     * @param fieldProviders 
     */
    public void setAvailableFieldProviders(List<FieldProvider> fieldProviders){
        defaultComboBoxModel.removeAllElements();
        for(FieldProvider fieldProvider : fieldProviders){
            defaultComboBoxModel.addElement(fieldProvider);
        }
    }
    
    /**
     * 
     * @return Selected fieldprovider
     */
    public FieldProvider getSelectedFieldProvider(){
        // Casting is save, model only has fieldProviders
        return (FieldProvider) defaultComboBoxModel.getSelectedItem();
    }
    

}
